#!/bin/bash
# -*- mode:sh; -*-
# Time-stamp: <2025-07-15 20:29:32 lockywolf>
#+title: 
#+author: 
#+date: 
#+created: <2025-07-15 Tue 16:48:25>
#+refiled:
#+language: bash
#+category: 
#+filetags: 
#+creator: Emacs-31.0.50/org-mode-9.8-pre


#sed 's/a/A/g;s/b/B/g;s/c/C/g;s/d/D/g;s/e/E/g;s/f/F/g;'

set -e

for char in а б в г д е ё ж з и й к л м н о п р с т у ф х ц ч ш щ ъ ы ь э ю я ; do
  printf '#utf-8 stringchar '
  printf '%s' $char | od -A n -t x1 | sed 's/ /\\\\x/g' | xargs  printf '%s '  | sed 's/a/A/g;s/b/B/g;s/c/C/g;s/d/D/g;s/e/E/g;s/f/F/g;'
  printf '%s' ${char^} | od -A n -t x1 | sed 's/ /\\\\x/g' | xargs  printf '%s '  | sed 's/a/A/g;s/b/B/g;s/c/C/g;s/d/D/g;s/e/E/g;s/f/F/g;' 
  printf '# '
  printf '%s %s\n' $char ${char^}
done

